Module executor

Module executor 

Structs

FakeError
Error type for the fake executor, can be transient or non-transient.
FakeExecutor
Fake executor for testing retry behavior.

Traits

RedisCommandExecutor
Abstraction over a Redis connection that can execute commands.

Functions

execute_with_retry
Executes a command with retry on transient errors, using NetworkRetryPolicy.