pub struct RedisComponent { /* private fields */ }Implementations
Sourceimpl RedisComponent
impl RedisComponent
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new RedisComponent without global config defaults.
Endpoint configs will fall back to hardcoded defaults via resolve_defaults().
Sourcepub fn with_config(config: RedisConfig) -> Self
pub fn with_config(config: RedisConfig) -> Self
Create a RedisComponent with global config defaults.
These will be applied to endpoint configs before resolve_defaults().
Sourcepub fn with_optional_config(config: Option<RedisConfig>) -> Self
pub fn with_optional_config(config: Option<RedisConfig>) -> Self
Create a RedisComponent with optional global config defaults.
If None, behaves like new() (uses hardcoded defaults only).